==> premium_primitives-0.0.1.tar.gz: premium_primitives-0.0.1/README.md <==
# Premium Primitives

<p align="center">
    <a href="https://github.com/alteryx/premium_primitives/actions/workflows/unit_tests_with_latest_deps.yaml?query=branch%3Amain" target="_blank">
        <img src="https://github.com/alteryx/premium_primitives/actions/workflows/unit_tests_with_latest_deps.yaml/badge.svg?branch=main" alt="Tests" />
    </a>
    <a href="https://codecov.io/gh/alteryx/premium_primitives" >
      <img src="https://codecov.io/gh/alteryx/premium_primitives/branch/main/graph/badge.svg?token=L9KINVJ31P"/>
    </a>
    <a href="https://stackoverflow.com/questions/tagged/featuretools" target="_blank">
        <img src="http://img.shields.io/badge/questions-on_stackoverflow-blue.svg" alt="StackOverflow" />
    </a>
</p>
<hr>

Premium Primitives is a package to use with [Featuretools](https://github.com/alteryx/featuretools) that provides additional primitives for feature generation.
```bash
python -m pip install featuretools[primitives]
```

## Support
The Featuretools community is happy to provide support to users of Featuretools. Project support can be found in four places depending on the type of question:

1. For usage questions, use [Stack Overflow](https://stackoverflow.com/questions/tagged/featuretools) with the `featuretools` tag.
2. For bugs, issues, or feature requests start a [Github issue](https://github.com/alteryx/premium_primitives/issues).
3. For discussion regarding development on the core library, use [Slack](https://join.slack.com/t/alteryx-oss/shared_invite/zt-182tyvuxv-NzIn6eiCEf8TBziuKp0bNA).
4. For everything else, the core developers can be reached by email at open_source_support@alteryx.com

## Built at Alteryx

**Featuretools** is an open source project maintained by [Alteryx](https://www.alteryx.com). To see the other open source projects we’re working on visit [Alteryx Open Source](https://www.alteryx.com/open-source). If building impactful data science pipelines is important to you or your business, please get in touch.

<p align="center">
  <a href="https://www.alteryx.com/open-source">
    <img src="https://alteryx-oss-web-images.s3.amazonaws.com/OpenSource_Logo-01.png" alt="Alteryx Open Source" width="800"/>
  </a>
</p>

==> premium_primitives-0.1.0.tar.gz: premium_primitives-0.1.0/README.md <==
# Premium Primitives

<p align="center">
    <a href="https://github.com/alteryx/premium_primitives/actions/workflows/unit_tests_with_latest_deps.yaml?query=branch%3Amain" target="_blank">
        <img src="https://github.com/alteryx/premium_primitives/actions/workflows/unit_tests_with_latest_deps.yaml/badge.svg?branch=main" alt="Tests" />
    </a>
    <a href="https://codecov.io/gh/alteryx/premium_primitives" >
      <img src="https://codecov.io/gh/alteryx/premium_primitives/branch/main/graph/badge.svg?token=L9KINVJ31P"/>
    </a>
    <a href="https://stackoverflow.com/questions/tagged/featuretools" target="_blank">
        <img src="http://img.shields.io/badge/questions-on_stackoverflow-blue.svg" alt="StackOverflow" />
    </a>
</p>
<hr>

Premium Primitives is a package to use with [Featuretools](https://github.com/alteryx/featuretools) that provides additional primitives for feature generation.
```bash
python -m pip install featuretools[premium]
```

## Support
The Featuretools community is happy to provide support to users of Featuretools. Project support can be found in four places depending on the type of question:

1. For usage questions, use [Stack Overflow](https://stackoverflow.com/questions/tagged/featuretools) with the `featuretools` tag.
2. For bugs, issues, or feature requests start a [Github issue](https://github.com/alteryx/premium_primitives/issues).
3. For discussion regarding development on the core library, use [Slack](https://join.slack.com/t/alteryx-oss/shared_invite/zt-182tyvuxv-NzIn6eiCEf8TBziuKp0bNA).
4. For everything else, the core developers can be reached by email at open_source_support@alteryx.com

## Built at Alteryx

**Featuretools** is an open source project maintained by [Alteryx](https://www.alteryx.com). To see the other open source projects we’re working on visit [Alteryx Open Source](https://www.alteryx.com/open-source). If building impactful data science pipelines is important to you or your business, please get in touch.

<p align="center">
  <a href="https://www.alteryx.com/open-source">
    <img src="https://alteryx-oss-web-images.s3.amazonaws.com/OpenSource_Logo-01.png" alt="Alteryx Open Source" width="800"/>
  </a>
</p>
